@@ -15,13 +15,42 @@ mgmsampler <- function(factors,
 {
   
   
-  # ---------- Input Checks ----------
-  
-  # ----- Compute aux vars -----
+  # ----- Compute basic aux vars -----
   
   p <- length(type)
   n_order <- length(lapply(interactions, function(x) 1))
   
+  
+  # ---------- Input Checks ----------
+  
+  # Check whether level are correctly specified according to type
+  if(any(level[type!="c"] != 1)) stop("The levels of all non-categorical variable has to be specified as c(1).")
+
+  # Check whether all interactions are specified in the correct dimension
+  for(ord in 1:n_order) {
+    
+    rows_ord <- nrow(factors[[ord]])
+    
+    for(row in 1:rows_ord) {
+      
+      if(!all(level[factors[[ord]][row, ]] == dim(interactions[[ord]][[row]]))) {
+        stop(paste0("The dimensions of the interaction ",
+                    paste0(factors[[ord]][row, ], collapse = "-"), 
+                           " is specified incorrectly. Please correct the 'interactions' argument."
+                    ))
+      }
+
+    } # end for: rows (interactions)
+  } # end for: ord
+
+  
+  # Are all parameters specified as matrices?
+  for(i in 1:n_order) {
+    n_ints <- length(interactions[[i]])
+    for(row in 1:n_ints) if(class( interactions[[i]][[row]]) != "matrix") stop("The parameters of each interaction have to be provided as k-dimensional array.")
+  }
+  
+  
   # ----- Input Checks -----
   
   # 1) Do matrices in factors match the corresponding order?
@@ -68,7 +97,7 @@ mgmsampler <- function(factors,
   # 5) Other basics
   if(length(type) != length(level)) stop('Length of type does not match length of level.')
   if(length(thresholds) != length(type)) stop('Length of threshold list does notmatch length of type vector')
-  if(!all.equal(unlist(lapply(thresholds, length)), level)) stop('Specified thresholds do not match the number of categoreis in level')
+  if(!all.equal(unlist(lapply(thresholds, length)), level)) stop('Specified thresholds do not match the number of categories in level')
   
   
   # Transforms all entries in factors and interactions into matrices to avoid trouble with nrow()
@@ -156,7 +185,7 @@ mgmsampler <- function(factors,
                   
                   for(k in f_ind) { # loop over variables in factor
                     
-                    # Gibbs algorithm: take always the freshest data
+                    # Gibbs algorithm: take always the fresh data
                     if(k >= v) gibbs_shift <- iter - 1 else gibbs_shift <- iter # equal case doesn't matter as excluded below
                     
                     if(level[k]==1) fill_in[k_counter] <- 1 else fill_in[k_counter] <- sampling_seq[gibbs_shift, k]
@@ -200,7 +229,7 @@ mgmsampler <- function(factors,
           if(type[v] == 'g') sampling_seq[iter, v] <- rnorm(1, mean = natPar, sd = sds[v])
           
           if(type[v] == 'p') {
-            if(natPar < 0) stop(paste0('Lambda parameter of Poisson variable ', v, ' is negative. Sampler returns NA.'))
+            if(natPar <= 0) stop(paste0('Lambda parameter of Poisson variable ', v, ' is nonpositive. Sampler returns NA.'))
             sampling_seq[iter, v] <- rpois(1, lambda = natPar)
           }
           
@@ -244,7 +273,7 @@ mgmsampler <- function(factors,
                     
                     for(k in f_ind) { # loop over variables in factor
                       
-                      # Gibbs algorithm: take always the freshest data
+                      # Gibbs algorithm: take always the fresh data
                       if(k >= v) gibbs_shift <- iter - 1 else gibbs_shift <- iter # equal case doesn't matter as excluded below
                       
                       # level[k]==1 indicates a continuous varibale
@@ -258,15 +287,14 @@ mgmsampler <- function(factors,
                     if(any(abs(sampling_seq[!is.na(sampling_seq)]) > divWarning)) warning('Gibbs Sampler diverged; adapt parameterization of continuous varibales.')
                     
                     # fill in current category
-                    fill_in[which(v == f_ind)] <- cat # we fix the category of v to cat in 1:level, since we compute all level potentials
+                    fill_in[which(v == f_ind)] <- cat # we set the category of the variable at hand to the cat we loop over; we fix the category of v to cat in 1:level, since we compute all level potentials
                     
                     # prepare fill in matrix:
                     m_fill_in <- matrix(fill_in, ncol=length(fill_in))
                     
                     # get the parameter for ord-interaction out the the ord-order parameter array
                     row_int <- interactions[[ord]][[row]][m_fill_in]
-
-                    
+      
                     # multiply it by continuous variables if in interaction and save in list
                     l_row_terms[[row_counter]] <- prod(get_cont[-which(f_ind == v)]) * row_int
                     
